#
# spec file for package python-flickrapi
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-flickrapi
Version:        2.4.0
Release:        3.7
Summary:        Python interface to Flickr
License:        Python-2.0
Group:          Development/Libraries/Python
URL:            http://stuvel.eu/projects/flickrapi
Source0:        https://files.pythonhosted.org/packages/source/f/flickrapi/flickrapi-%{version}.tar.gz
# https://github.com/sybrenstuvel/flickrapi/commit/e47e62df304d36ae81c483230bb41e6f4dde8bfd
Patch0:         python-flickrapi-no-python2.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module requests-oauthlib >= 0.4.2}
BuildRequires:  %{python_module requests-toolbelt >= 0.3.1}
BuildRequires:  %{python_module requests >= 2.4.3}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 2.4.3
Requires:       python-requests-oauthlib >= 0.4.2
Requires:       python-requests-toolbelt >= 0.3.1
BuildArch:      noarch
%ifpython2
Provides:       python-flickrapi-doc = %{version}
Obsoletes:      python-flickrapi-doc < %{version}
%endif
%python_subpackages

%description
The easiest to use, most complete, and most actively developed
Python interface to the Flickr API. It includes support for
authorized and non-authorized access, uploading and replacing
photos, and all Flickr API functions.

%prep
%setup -q -n flickrapi-%{version}
%patch0 -p1
sed -i "1d" flickrapi/__init__.py # Fix non-executable script

%build
%pyproject_wheel

%install
%pyproject_install
rm -rf %{buildroot}%{python_sitelib}/*.txt # Remove wrongly installed documentation
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%license LICENSE.txt
%doc README.md
%{python_sitelib}/*

%changelog
* Fri Oct 21 2022 pgajdos@suse.com
- do not require six
- added patches
  https://github.com/sybrenstuvel/flickrapi/commit/e47e62df304d36ae81c483230bb41e6f4dde8bfd
  + python-flickrapi-no-python2.patch
* Tue Jun 29 2021 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded BuildRequires on python-devel
* Thu Dec  6 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 2.4.0:
  * Fix parameter naming conflict: 'method_name' parameter from do_flickr_call() clashed with 'method_name' parameter required by the Flickr API method flickr.reflection.getMethodInfo (since 952c133
  * Fixed typos [ Pull request #86 ] (Daniel Hohard)
  * Fixed infinite recursion calling FlickrAccessToken.str()
  * Use latest pip and enable cache on travis [ Pull request #100 ] (Thijs Triemstra)
  * Properly include text files in setup.py [ Pull request #101 ] (Thijs Triemstra)
- Fix fdupes call
* Tue May 16 2017 dmueller@suse.com
- update to 2.3:
  - Removed flickrapi/contrib.py, as a persistent connection is now managed (much better)
  - Added explicit support for Python 3.5.
  - Moved from a Mercurial repository at BitBucket to a [Git repository
    at GitHub](https://github.com/sybrenstuvel/flickrapi/).
  - Mocking some calls to Flickr, so that unit tests can run without
    requiring the user to authenticate via the browser. This also
    prevents the upload of the test photo.
  - More serious testing, using py.test and Tox to test on all support
    versions of Python.
  - Automated builds are performed with Travis-CI.
  - Make flickrapi token storage directory configurable.
    [[ Feature request #68 ]](https://github.com/sybrenstuvel/flickrapi/issues/68)
  - Put requests in a session to benefit from connection reuse (Alexandre L).
  - When uploading a photo, send the title as UTF8
  - Sort many photosets with 'flickr.photosets.orderSets' failed
    [[ Bug report #74]](https://github.com/sybrenstuvel/flickrapi/issues/74)
  - Converted requested_permissions to unicode and ported authentication
    example to Python 3 (Michael Klich).
* Tue May  5 2015 benoit.monin@gmx.fr
- update to version 2.0:
  * Major revision; now uses OAuth to interface with Flickr.
    Combines work of Sybren A. Stüvel, Jim Easterbrook,
    Thai Nguyen, Nick Loadholtes and Bengt.
- drop flickrapi-drop-bootstrap-distribute.patch: fixed upstream
- point the source URL to pypi
- remove unneeded depedencies to python-docutils, python-xml
  and unzip
- add new dependencies required by upstream:
  * python-requests
  * python-requests-oauthlib
  * python-requests-toolbelt
  * python-six
- always requires fdupes and run it after install
- define python_sitelib only for SLE11
- doc is not provided anymore: do not build it
- rename LICENSE, README, UPGRADING to LICENSE.txt, README.txt,
  UPGRADING.txt: changed upstream
* Mon Sep 16 2013 mvyskocil@suse.com
- don't use distribute bootstrapping code as it attempt to download files
  * flickrapi-drop-bootstrap-distribute.patch
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Thu Sep 22 2011 saschpe@suse.de
- BuildRequire python-docutils instead of old docutils
* Wed Sep 21 2011 saschpe@suse.de
- Update to version 1.4.0:
  * No changes provided by upstream
- Spec file cleanup:
  * Proper suse version checks
  * Removed old stuff (%%clean section)
  * Corrected docs install location, generate HTML docs
  * Obsolete doc package, ship in base package
  * Fix non-executable bit rpmlint warning
* Fri Sep  3 2010 jmatejek@novell.com
- fixed python version in filelist
* Fri Jan 22 2010 vuntz@opensuse.org
- Initial packaging, with version 1.3.
